@@ -420,9 +420,11 @@ class InstallPackagesCLI():
                 raise SysExit(125)
             break
 
-    def discard_install_info(self, canceled_pkg_name: str) -> None:
+    def discard_install_info(self, canceled_pkg_name: str, ignore=True) -> None:
         debug(f"discarding install info for pkg... {canceled_pkg_name}")
-        self.manually_excluded_packages_names.append(canceled_pkg_name)
+        if ignore:
+            debug(f"ignoring pkg... {canceled_pkg_name}")
+            self.manually_excluded_packages_names.append(canceled_pkg_name)
         if not getattr(self, 'install_info', None):  # @TODO: make it nicer?
             debug("install info not initialized yet -- running on early stage?")
             return
@@ -438,7 +440,11 @@ class InstallPackagesCLI():
     def _find_extra_aur_build_deps(self, all_package_builds: Dict[str, PackageBuild]):
         need_to_show_install_prompt = False
         for pkgbuild in all_package_builds.values():
-            pkgbuild.get_deps(all_package_builds=all_package_builds, filter_built=False)
+            pkgbuild.get_deps(
+                all_package_builds=all_package_builds,
+                filter_built=False,
+                exclude_pkg_names=self.manually_excluded_packages_names
+            )
 
             aur_pkgs: List[AURPackageInfo] = [
                 info.package  # type: ignore[misc]
@@ -458,6 +464,8 @@ class InstallPackagesCLI():
 
             srcinfo_deps: Set[str] = set()
             for package_name in pkgbuild.package_names:
+                if package_name in self.manually_excluded_packages_names:
+                    continue
                 src_info = SrcInfo(pkgbuild_path=pkgbuild.pkgbuild_path, package_name=package_name)
                 srcinfo_deps.update(set(
                     dep_line
@@ -482,17 +490,24 @@ class InstallPackagesCLI():
                         deps=bold_line(', '.join(deps_removed)),
                     ))
                 for pkg_name in pkgbuild.package_names:
-                    self.discard_install_info(pkg_name)
+                    self.discard_install_info(pkg_name, ignore=False)
                 self.pkgbuilds_packagelists[pkgbuild.pkgbuild_path] = pkgbuild.package_names
                 need_to_show_install_prompt = True
         if need_to_show_install_prompt:
             self.main_sequence()
             raise self.ExitMainSequence()
 
-    def _clone_aur_repos(self, package_names: List[str]) -> Optional[Dict[str, PackageBuild]]:
+    def _clone_aur_repos(  # pylint: disable=too-many-branches
+            self, package_names: List[str]
+    ) -> Optional[Dict[str, PackageBuild]]:
+        stash_pop_list: List[str] = []
         while True:
             try:
-                return clone_aur_repos(package_names=package_names)
+                pkgbuild_by_name = clone_aur_repos(package_names=package_names)
+                for pkg_build in pkgbuild_by_name.values():
+                    if pkg_build.package_base in stash_pop_list:
+                        pkg_build.git_stash_pop()
+                return pkgbuild_by_name
             except CloneError as err:
                 package_build = err.build
                 print_stderr(color_line(
@@ -511,20 +526,26 @@ class InstallPackagesCLI():
                 if self.args.noconfirm:
                     answer = _("a")
                 else:  # pragma: no cover
-                    prompt = '{} {}\n{}\n{}\n{}\n{}\n> '.format(
+                    prompt = '{} {}\n> '.format(
                         color_line('::', 11),
-                        _("Try recovering?"),
-                        _("[c] git checkout -- '*'"),
-                        # _("[c] git checkout -- '*' ; git clean -f -d -x"),
-                        _("[r] remove dir and clone again"),
-                        _("[s] skip this package"),
-                        _("[A] abort")
+                        '\n'.join((
+                            _("Try recovering?"),
+                            _("[c] git checkout -- '*'"),
+                            # _("[c] git checkout -- '*' ; git clean -f -d -x"),
+                            _("[r] remove dir and clone again"),
+                            _("[p] git stash && ... && git stash pop"),
+                            _("[s] skip this package"),
+                            _("[A] abort")
+                        ))
                     )
                     answer = get_input(prompt, _('c') + _('r') + _('s') + _('a').upper())
 
                 answer = answer.lower()[0]
                 if answer == _("c"):  # pragma: no cover
                     package_build.git_reset_changed()
+                elif answer == _("p"):  # pragma: no cover
+                    package_build.git_stash()
+                    stash_pop_list.append(package_build.package_base)
                 elif answer == _("r"):  # pragma: no cover
                     remove_dir(package_build.repo_path)
                 elif answer == _("s"):  # pragma: no cover
@@ -775,7 +796,7 @@ class InstallPackagesCLI():
 
     def handle_pkgbuild_changed(self, pkg_build: PackageBuild) -> None:
         for pkg_name in pkg_build.package_names:
-            self.discard_install_info(pkg_name)
+            self.discard_install_info(pkg_name, ignore=False)
         src_info = SrcInfo(pkgbuild_path=pkg_build.pkgbuild_path)
         old_srcinfo_hash = hash_file(src_info.path)
         src_info.regenerate()
@@ -863,7 +884,8 @@ class InstallPackagesCLI():
                     f"Build done for packages {pkg_build.package_names=}, removing from queue"
                 )
                 for _pkg_name in pkg_build.package_names:
-                    packages_to_be_built.remove(_pkg_name)
+                    if _pkg_name not in self.manually_excluded_packages_names:
+                        packages_to_be_built.remove(_pkg_name)
 
         self.failed_to_build_package_names = failed_to_build_package_names
 
